@@ -25,6 +25,16 @@
 #include <ctype.h>
 #include <stdlib.h>
 
+#ifdef HAVE_MY_GLOBAL_H
+#include <my_global.h>
+#elif defined(HAVE_MYSQL_MY_GLOBAL_H)
+#include <mysql/my_global.h>
+#endif
+#ifdef HAVE_MY_SYS_H
+#include <my_sys.h>
+#elif defined(HAVE_MYSQL_MY_SYS_H)
+#include <mysql/my_sys.h>
+#endif
 #ifdef HAVE_MYSQL_H
 #include <mysql.h>
 #include <errmsg.h>
